@@ -42,13 +42,15 @@ impl Message for DynamicMessage {
         Self: Sized,
     {
         if let Some(field_desc) = self.desc.get_field(number) {
-            self.fields
-                .get_mut(&field_desc)
+            self.get_field_mut(&field_desc)
                 .merge_field(&field_desc, wire_type, buf, ctx)
         } else if let Some(extension_desc) = self.desc.get_extension(number) {
-            self.extension_fields_mut()
-                .get_mut(&extension_desc)
-                .merge_field(&extension_desc, wire_type, buf, ctx)
+            self.get_extension_mut(&extension_desc).merge_field(
+                &extension_desc,
+                wire_type,
+                buf,
+                ctx,
+            )
         } else {
             self.unknown_fields_mut()
                 .merge_field(number, wire_type, buf, ctx)
